@@ -3,7 +3,7 @@ import copy
 from Orange.data import ContinuousVariable, Domain, Table
 
 
-def create_embeddings(table, model, progress_callback=None, argself=None):
+def create_embeddings(table, model, column_name, progress_callback=None, argself=None):
     if len(table) == 0:
         return None
     # Copy of input data
@@ -19,7 +19,7 @@ def create_embeddings(table, model, progress_callback=None, argself=None):
         features = [row[x] for x in attr_dom]
         targets = [row[y] for y in class_dom]
         metas = list(data.metas[i])
-        embeddings = model.encode(str(row["content"]), show_progress_bar=False)
+        embeddings = model.encode(str(row[column_name]), show_progress_bar=False)
         features += list(embeddings)
         rows.append(features + targets + metas)
         if progress_callback is not None:
