@@ -359,20 +359,24 @@ if platform.system() == "Darwin":
                     repeat with _f in _fs
                         set end of _list to POSIX path of _f
                     end repeat
-                    return _list as string -- AppleScript joint par ", " par défaut, donc faisons mieux :
+
+                    -- On change temporairement le séparateur texte d'AppleScript
+                    set oldDelims to AppleScript's text item delimiters
+                    set AppleScript's text item delimiters to "//////"
+                    set _joined to _list as text
+                    set AppleScript's text item delimiters to oldDelims
+
+                    return _joined
                 on error number -128
                     return ""
                 end try
             end timeout
             '''
-            # On exécute puis on convertit la liste AppleScript (qui reviendra "p1, p2, p3") en ';' côté Python
             cp = _run_osascript(script)
             raw = cp.stdout.strip()
             if not raw:
                 return ""
-            # AppleScript renvoie les listes avec ", " ; on découpe prudemment
-            parts = [p.strip() for p in raw.split(",") if p.strip()]
-            return str(";".join(parts))
+            return raw  # le string avec les chemins séparés par //////
         else:
             script = f'''
             with timeout of 3600 seconds
@@ -389,6 +393,7 @@ if platform.system() == "Darwin":
             cp = _run_osascript(script)
             return cp.stdout.strip()
 
+
     # ----------------------------
     # 3) Enregistrer sous (nouveau fichier)
     # ----------------------------
