@@ -276,13 +276,12 @@ if os.name=='nt':
         # Split sur \0
         parts = buffer_content.split('\0')
         parts = [p.replace("\\", "/") for p in parts if p]
-
         if multi_select:
             if len(parts) >= 2:
                 folder = parts[0]
                 files = parts[1:]
                 full_paths = [f"{folder}/{file}" for file in files]
-                return ';'.join(full_paths)
+                return '//////'.join(full_paths)
             elif len(parts) == 1:
                 return parts[0]
             else:
