@@ -196,7 +196,7 @@ class OWAAITResourcesManager(widget.OWWidget):
         QTimer.singleShot(0, self.close)
     def open_explorer(self):
         path = MetManagement.get_local_store_path()
-        if sys.platform.startswith("darwin"):
+        if sys.platform.startswith("Darwin") or sys.platform.startswith("darwin"):
             import subprocess
             subprocess.run(["open", path])
             return
