@@ -1,7 +1,7 @@
 import os
 
 import Orange.data
-from Orange.widgets import widget
+from Orange.data import StringVariable
 from Orange.widgets.utils.signals import Input, Output
 from Orange.widgets.settings import Setting
 from AnyQt.QtWidgets import QLineEdit
@@ -11,17 +11,15 @@ from sentence_transformers import SentenceTransformer
 
 if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
     from Orange.widgets.orangecontrib.AAIT.llm import chunking
-    from Orange.widgets.orangecontrib.AAIT.utils import thread_management
-    from Orange.widgets.orangecontrib.AAIT.utils.import_uic import uic
+    from Orange.widgets.orangecontrib.AAIT.utils import thread_management, base_widget
     from Orange.widgets.orangecontrib.AAIT.utils.initialize_from_ini import apply_modification_from_python_file
 else:
     from orangecontrib.AAIT.llm import chunking
-    from orangecontrib.AAIT.utils import thread_management
-    from orangecontrib.AAIT.utils.import_uic import uic
+    from orangecontrib.AAIT.utils import thread_management, base_widget
     from orangecontrib.AAIT.utils.initialize_from_ini import apply_modification_from_python_file
 
 @apply_modification_from_python_file(filepath_original_widget=__file__)
-class OWChunker(widget.OWWidget):
+class OWChunker(base_widget.BaseListWidget):
     name = "Text Chunker"
     description = "Create chunks on the column 'content' of a Table"
     icon = "icons/owchunking.png"
@@ -32,6 +30,12 @@ class OWChunker(widget.OWWidget):
     priority = 1050
     category = "AAIT - LLM INTEGRATION"
 
+    # Settings
+    chunk_size: str = Setting("300")
+    overlap: str = Setting("100")
+    mode: str = Setting("words")
+    selected_column_name = Setting("content")
+
     class Inputs:
         data = Input("Data", Orange.data.Table)
         model = Input("Model", SentenceTransformer, auto_summary=False)
@@ -39,16 +43,13 @@ class OWChunker(widget.OWWidget):
     class Outputs:
         data = Output("Chunked Data", Orange.data.Table)
 
-    chunk_size: str = Setting("300")
-    overlap: str = Setting("100")
-    mode: str = Setting("words")
 
     @Inputs.data
     def set_data(self, in_data):
-        if in_data is None:
-            self.Outputs.data.send(None)
-            return
         self.data = in_data
+        if self.data:
+            self.var_selector.add_variables(self.data.domain)
+            self.var_selector.select_variable_by_name(self.selected_column_name)
         if self.autorun:
             self.run()
 
@@ -62,8 +63,8 @@ class OWChunker(widget.OWWidget):
         super().__init__()
         # Qt Management
         self.setFixedWidth(470)
-        self.setFixedHeight(300)
-        uic.loadUi(self.gui, self)
+        self.setFixedHeight(490)
+        #uic.loadUi(self.gui, self)
 
 
         self.edit_mode = self.findChild(QComboBox, "comboBox")
@@ -102,47 +103,35 @@ class OWChunker(widget.OWWidget):
         self.mode = selected
 
     def run(self):
+        self.error("")
+        self.warning("")
+
         # if thread is running quit
-        """
-        Main function of the widget. It segments the text into chunks of approximately
-        400 words, stopping at sentence boundaries.
-
-        If a thread is already running, it will be terminated.
-
-        The function will also check if the input data contains a column named "content"
-        and if it is a text variable. If not, an error message will be displayed.
-
-        The function will then start a progress bar and a new thread with the
-        chunk_data function. The thread will be connected to the progress bar,
-        as well as to the result and finish signals.
-
-        :return: None
-        """
-
         if self.thread is not None:
             self.thread.safe_quit()
 
         if self.data is None:
+            self.Outputs.data.send(None)
             return
 
         if self.model is None:
+            self.Outputs.data.send(None)
             return
 
         # Verification of in_data
-        self.error("")
-        if not "content" in self.data.domain:
-            self.error('You need a "content" column in input data')
+        if not self.selected_column_name in self.data.domain:
+            self.warning(f'Previously selected column "{self.selected_column_name}" does not exist in your data.')
             return
 
-        if type(self.data.domain["content"]).__name__ != 'StringVariable':
-            self.error('"content" column needs to be a Text')
+        if not isinstance(self.data.domain[self.selected_column_name], StringVariable):
+            self.error('You must select a text variable.')
             return
 
         # Start progress bar
         self.progressBarInit()
 
         # Connect and start thread
-        self.thread = thread_management.Thread(chunking.create_chunks, self.data, self.model, int(self.chunk_size), int(self.overlap), str(self.mode))
+        self.thread = thread_management.Thread(chunking.create_chunks, self.data, self.model, self.selected_column_name, int(self.chunk_size), int(self.overlap), str(self.mode))
         self.thread.progress.connect(self.handle_progress)
         self.thread.result.connect(self.handle_result)
         self.thread.finish.connect(self.handle_finish)
