@@ -498,50 +498,6 @@ class OWCorpusViewer(OWWidget, ConcurrentWidgetMixin):
         self.show_docs()
         self.commit.deferred()
 
-    def show_docs(self):
-        """Show the selected documents in the right area"""
-        if self.corpus is None:
-            return
-
-        self.Warning.no_feats_display.clear()
-        if len(self.display_features) == 0:
-            self.Warning.no_feats_display()
-
-        if self.show_tokens:
-            tokens = list(self.corpus.ngrams_iterator(include_postags=True))
-
-        parts = []
-        for doc_count, c_index in enumerate(sorted(self.selected_documents)):
-            text = ""
-            for feature in self.display_features:
-                value = str(self.corpus[c_index, feature.name])
-                if feature in self.search_features:
-                    value = self.__mark_text(value)
-                value = value.replace("\n", "<br/>")
-                is_image = feature.attributes.get("type", "") == "image"
-                if is_image and value != "?":
-                    value = os.path.join(feature.attributes.get("origin", ""), value)
-                    value = '<img src="{}"></img>'.format(value)
-                text += (
-                    f'<tr><td class="variables"><strong>{feature.name}:</strong></td>'
-                    f'<td class="content">{value}</td></tr>'
-                )
-
-            if self.show_tokens:
-                tokens_ = "".join(
-                    f'<span class="token">{token}</span>' for token in tokens[c_index]
-                )
-                text += (
-                    f'<tr><td class="variables"><strong>Tokens & Tags:</strong></td>'
-                    f"<td>{tokens_}</td></tr>"
-                )
-            parts.append(text)
-
-        joined = SEPARATOR.join(parts)
-        html = f"<table>{joined}</table>"
-        base = QUrl.fromLocalFile(__file__)
-        if self.doc_webview is not None:
-            self.doc_webview.setHtml(HTML.format(html), base)
 
     def __mark_text(self, text):
         search_keyword = self.regexp_filter.strip("|")
@@ -691,22 +647,12 @@ class OWCorpusViewer(OWWidget, ConcurrentWidgetMixin):
     def convert_markdown_with_syntax_highlighting(self, markdown_text, base_path=""):
         """
         Convertit le texte Markdown avec syntaxe de code colorée en HTML.
-
-        Utilise la bibliothèque 'markdown' pour convertir le texte Markdown
-        en HTML, en incluant les extensions 'fenced_code' et 'codehilite'
-        pour la syntaxe de code colorée.
-
-        Les options de configuration sont définies pour que la bibliothèque
-        'codehilite' utilise les classes CSS pour la coloration syntaxique,
-        et pour qu'elle ne tente pas de deviner le langage du code.
-
-        Args :
-            markdown_text (str) : Le texte Markdown à convertir.
-
-        Returns :
-            str : Le texte HTML converti.
         """
 
+        # --- Patch : normaliser les listes pour que les puces après un "1." restent des sous-listes ---
+        markdown_text = self._normalize_lists_for_markdown(markdown_text)
+        # ---------------------------------------------------------------------
+
         # Convertir le Markdown en HTML avec extensions pour le code
         html_content = markdown.markdown(
             markdown_text,
@@ -720,7 +666,6 @@ class OWCorpusViewer(OWWidget, ConcurrentWidgetMixin):
             }
         )
 
-
         # Ajouter le CSS pour Pygments
         css = HtmlFormatter().get_style_defs('.codehilite')
         html_content = f"<style>{css}</style>{html_content}"
@@ -729,6 +674,52 @@ class OWCorpusViewer(OWWidget, ConcurrentWidgetMixin):
         html_content = self.adjust_image_paths(html_content, base_path)
         return html_content
 
+    def _normalize_lists_for_markdown(self, text: str) -> str:
+        """
+        Transforme les puces qui suivent immédiatement un item numéroté
+        en sous-liste (en les indentant), pour éviter une renumérotation 1,2,3,4,5.
+
+        Exemple :
+            1. Titre
+            2. Autre titre
+            - sous-étape
+            - sous-étape
+
+        devient :
+            1. Titre
+            2. Autre titre
+                - sous-étape
+                - sous-étape
+        """
+        lines = text.splitlines()
+        out = []
+        in_ordered_list = False
+
+        for line in lines:
+            stripped = line.lstrip()
+
+            # Ligne d'une liste numérotée : "1. xxx"
+            if re.match(r'^\d+\.\s+', stripped):
+                in_ordered_list = True
+                # On normalise en supprimant l'indentation superflue éventuelle
+                out.append(stripped)
+                continue
+
+            # Ligne d'une puce qui suit une liste numérotée
+            if in_ordered_list and re.match(r'^[-*+]\s+', stripped):
+                # Si elle n'est pas déjà indentée, on l'indente comme sous-liste
+                if not line.startswith('    '):
+                    out.append('    ' + stripped)
+                else:
+                    out.append(line)
+                continue
+
+            # Autre contenu : on sort du contexte "liste numérotée"
+            in_ordered_list = False
+            out.append(line)
+
+        return "\n".join(out)
+
     def adjust_image_paths(self, html_content, base_path):
         """
         Corrige les chemins d'images pour qu'ils soient valides même pour des chemins relatifs.
