@@ -25,7 +25,7 @@ class EndLoopWidget(OWWidget):
     priority = 1011
 
     class Inputs:
-        in_data = Input("Data In", Orange.data.Table)
+        in_data = Input("Data In", Orange.data.Table, multiple=True)
         in_pointer = Input("End of the Loop Do-While", str, auto_summary=False)
 
     class Outputs:
@@ -42,7 +42,7 @@ class EndLoopWidget(OWWidget):
         self.in_pointer = None
 
     @Inputs.in_data
-    def set_data(self, data):
+    def set_data(self, data,id=None):
         self.error("")
         if data is None:
             self.data = None
