@@ -64,13 +64,31 @@ class OWExtraChunks(widget.OWWidget):
         self.extra_chunks = int(text) if text.isdigit() else 2
 
     def process(self):
+        self.error("")
+        self.warning("")
+
         if self.complete_data is None or self.selected_data is None:
             self.Outputs.concatenate_data.send(None)
             self.Outputs.data.send(None)
             return
 
         domain = self.complete_data.domain
-        if "Chunks index" not in domain or "path" not in domain:
+        if "path" not in domain:
+            self.error(f'You need a "path" column in your input tables.')
+            self.Outputs.concatenate_data.send(None)
+            self.Outputs.data.send(None)
+            return
+
+        if "Chunks index" not in domain:
+            self.error(f'You need a "Chunks index" column in your input tables.')
+            self.Outputs.concatenate_data.send(None)
+            self.Outputs.data.send(None)
+            return
+
+        if "Chunks" not in domain:
+            self.error(f'You need a "Chunks" column in your input tables.')
+            self.Outputs.concatenate_data.send(None)
+            self.Outputs.data.send(None)
             return
 
         index_var = domain["Chunks index"]
@@ -114,7 +132,6 @@ class OWExtraChunks(widget.OWWidget):
         merged_results = self.merge_chunks(selected_rows)
         concat_domain = Orange.data.Domain([], metas=[
             Orange.data.StringVariable("path"),
-            Orange.data.StringVariable("name"),
             Orange.data.StringVariable("Merged Chunks")
         ])
         merged_table = Orange.data.Table.from_list(concat_domain, merged_results)
@@ -151,7 +168,6 @@ class OWExtraChunks(widget.OWWidget):
         for row in self.selected_data:
             path = row[self.complete_data.domain["path"]]
             index = int(row[self.complete_data.domain["Chunks index"]])
-            name = row[self.complete_data.domain["name"]]
 
             if path not in doc_groups:
                 continue  # Si le path n'existe pas, on passe
@@ -166,10 +182,11 @@ class OWExtraChunks(widget.OWWidget):
                 if i in doc_groups[path]:  # Vérifie que l'index existe
                     merged_text = self.remove_overlap(merged_text, doc_groups[path][i])
 
-            merged_results.append([path, name, merged_text])
+            merged_results.append([path, merged_text])
 
         return merged_results
 
+
 if __name__ == "__main__":
     import sys
     app = QApplication(sys.argv)
