@@ -61,7 +61,7 @@ class OWFileSyncChecker(widget.OWWidget):
 
         # Data Management
         self.data = None
-        self.reference = "default"
+        self.reference = None
         self.autorun = True
         self.thread = None
         self.result = None
@@ -77,13 +77,6 @@ class OWFileSyncChecker(widget.OWWidget):
                 self.thread.safe_quit()
 
         if self.data is None:
-            self.Outputs.data.send(None)
-            self.Outputs.processed.send(None)
-            return
-
-        if self.reference == "default":
-            self.Outputs.data.send(None)
-            self.Outputs.processed.send(None)
             return
 
         if self.reference is None:
@@ -147,8 +140,6 @@ class OWFileSyncChecker(widget.OWWidget):
             paths_ref[p] = int(row["file size"].value)
             ref_row_for_path[p] = i
 
-        progress_update(20, progress_callback)
-
         # ---- Compute aligned roots once ----
         def common_root(keys):
             if not keys:
@@ -168,9 +159,6 @@ class OWFileSyncChecker(widget.OWWidget):
                 new = p
             aligned_ref[new] = size
 
-
-        progress_update(50, progress_callback)
-
         set_data = set(paths_data.keys())
         set_ref = set(aligned_ref.keys())
 
@@ -192,21 +180,13 @@ class OWFileSyncChecker(widget.OWWidget):
                 if p in ref_row_for_path:
                     remove_indices.add(ref_row_for_path[p])
 
-        progress_update(60, progress_callback)
-
         for p in only_data:
             files_to_process.append([Path(p), paths_data[p]])
 
-
-        progress_update(70, progress_callback)
-
         for p in only_ref:
             if p in ref_row_for_path:
                 remove_indices.add(ref_row_for_path[p])
 
-
-        progress_update(80, progress_callback)
-
         # ---- Build new reference table once ----
         if remove_indices:
             keep_rows = [i for i in range(len(reference)) if i not in remove_indices]
@@ -221,8 +201,6 @@ class OWFileSyncChecker(widget.OWWidget):
             except Exception:
                 pass
 
-        progress_update(100, progress_callback)
-
         # ---- Build output table ----
         path_var = StringVariable("path")
         size_var = ContinuousVariable("file size")
@@ -242,8 +220,6 @@ class OWFileSyncChecker(widget.OWWidget):
         try:
             self.Outputs.data.send(data)
             self.Outputs.processed.send(processed_data)
-            self.data = None
-            self.reference = "default"
         except Exception as e:
             print("An error occurred when sending out_data:", e)
             self.Outputs.data.send(None)
@@ -257,12 +233,6 @@ class OWFileSyncChecker(widget.OWWidget):
         pass
 
 
-def progress_update(value, progress_callback):
-    if progress_callback is not None:
-        progress_value = float(value)
-        progress_callback(progress_value)
-
-
 def remove_from_table(filepath, table):
     """
     Remove rows from the Orange table where 'path' matches the given filepath.
